@@ -13,7 +13,8 @@ def uploadImage(url, token, payload):
     else:
         print(r)
         return False
-def downloadImage(url, token, classname):
+        
+def downloadAnnotations(url, token, classname):
     ''' 
     url : IoT.own Server Address
     token : IoT.own API Token
@@ -27,3 +28,18 @@ def downloadImage(url, token, classname):
     else:
         print(r)
         return None
+
+def downloadImage(url, token, imageID):
+    ''' 
+    url : IoT.own Server Address
+    token : IoT.own API Token
+    imageID : IoT.own imageID ( using annotation's 'id' not '_id' ) 
+    '''
+    apiaddr = url + "/nn/dataset/img/" + imageID
+    header = {'Accept':'application/json', 'token':token}
+    r = requests.get(apiaddr, headers=header)
+    if r.status_code == 200:
+        return r.content
+    else:
+        print(r)
+        return None
